@@ -23,7 +23,9 @@
 
 #------------------------------------------------------------------------------------------
 """
-This script is responsible for efficient uploading of multi file data
+Uploads specified set of data into ''study''. 
+This is one of the basic data exchange utility. 
+Usually appears in context of ''[[cloudflu-download]]'' utility.
 """
 
 
@@ -35,7 +37,7 @@ import cloudflu.amazon as amazon
 
 
 #------------------------------------------------------------------------------------------
-def entry_point( the_root_object, the_file2locations, the_upload_seed_size, the_number_threads, the_study_name = None, the_booked = False ) :
+def entry_point( the_root_object, the_file2locations, the_upload_seed_size, the_number_threads, the_socket_timeout, the_study_name = None, the_booked = False ) :
     a_spent_time = Timer()
     
     import study_book; 
@@ -53,7 +55,7 @@ def entry_point( the_root_object, the_file2locations, the_upload_seed_size, the_
     print_d( "a_located_files = %s\n" % a_located_files )
 
     import upload_resume; 
-    a_study_object = upload_resume.entry_point( a_study_object, a_located_files, the_number_threads )
+    a_study_object = upload_resume.entry_point( a_study_object, a_located_files, the_number_threads, the_socket_timeout )
     print_d( '\n' )
     
     print_d( "a_spent_time = %s, sec\n" % a_spent_time )
@@ -70,8 +72,9 @@ def main() :
     import data_seeding_options
 
     an_usage_description = "%prog"
-    an_usage_description += upload_start_options.usage_description()
+    an_usage_description += study_book_options.usage_description()
     an_usage_description += data_upload_options.usage_description()
+    an_usage_description += upload_start_options.usage_description()
     
     from cloudflu import VERSION
     a_version = "%s" % VERSION
@@ -108,7 +111,7 @@ def main() :
     
     AWS_ACCESS_KEY_ID, AWS_SECRET_ACCESS_KEY = amazon.security_options.extract( an_option_parser )
     
-    common.communication_options.extract( an_option_parser )
+    a_socket_timeout = common.communication_options.extract( an_option_parser )
 
     a_number_threads = common.concurrency_options.extract( an_option_parser )
     
@@ -128,7 +131,7 @@ def main() :
     
 
     print_i( "-------------------------- Running actual functionality -------------------------\n" )
-    a_study_object = entry_point( a_root_object, a_file2locations, an_upload_seed_size, a_number_threads, a_study_name, a_booked )
+    a_study_object = entry_point( a_root_object, a_file2locations, an_upload_seed_size, a_number_threads, a_socket_timeout, a_study_name, a_booked )
     
     
     print_i( "-------------------- Printing succussive pipeline arguments ---------------------\n" )
