@@ -23,7 +23,9 @@
 
 #------------------------------------------------------------------------------------------
 """
-Removes whole appointed cloud study or just given files from this study
+Removes specified ''study'' files, where the ''study'' is identified by its name. 
+This is one of the basic data introspection utility. 
+Usually appears in context of ''[[cloudflu-ls]]'' utility. 
 """
 
 #------------------------------------------------------------------------------------------
@@ -63,8 +65,6 @@ def main() :
     
     common.concurrency_options.add( an_option_parser )
     
-    common.communication_options.add( an_option_parser )
-    
     common.options.add( an_option_parser )
 
 
@@ -73,8 +73,6 @@ def main() :
 
     common.options.extract( an_option_parser )
 
-    common.communication_options.extract( an_option_parser )
-    
     a_number_threads = common.concurrency_options.extract( an_option_parser )
     
     AWS_ACCESS_KEY_ID, AWS_SECRET_ACCESS_KEY = amazon.security_options.extract( an_option_parser )
