@@ -38,15 +38,26 @@ from cloudflu.common import print_d, sh_command
 #------------------------------------------------------------------------------------------
 def upload_timedata( the_root_object, the_study_name, the_booked,
                      the_upload_seed_size, the_number_threads, the_socket_timeout,
-                     the_case_dir, the_item ) :
-    sh_command( "reconstructPar -case '%s' -time %s >> log.reconstructPar 2>&1" % ( the_case_dir, the_item ) )
+                     the_case_dir, the_item, the_current_dir_list ) :
+    try:
+        sh_command( "reconstructPar -case '%s' -time %s >> log.reconstructPar 2>&1" % ( the_case_dir, the_item ) )
 
-    import os.path; a_timestamp = os.path.join( the_case_dir, the_item )
-    import os.path; a_timestamp = os.path.abspath( a_timestamp )
+        import os.path; a_timestamp = os.path.join( the_case_dir, the_item )
+        import os.path; a_timestamp = os.path.abspath( a_timestamp )
     
-    import data_upload; data_upload.entry_point( the_root_object, { a_timestamp : '' }, 
-                                                 the_upload_seed_size, the_number_threads, the_socket_timeout,
-                                                 the_study_name, the_booked )
+        import data_upload; data_upload.entry_point( the_root_object, { a_timestamp : '' }, 
+                                                     the_upload_seed_size, the_number_threads, the_socket_timeout,
+                                                     the_study_name, the_booked )
+        return
+    except OSError, exc :
+        print "filename = %s\nstrerror = %s\errno = %s" % \
+            ( exc.filename, exc.strerror, exc.errno )
+    except Exception :
+        from cloudflu.common import print_traceback
+        print_traceback()
+        pass
+
+    the_current_dir_list.remove( the_item )
     pass
 
 
@@ -142,7 +153,7 @@ def main() :
     a_spent_time = common.Timer()
 
     import os.path; a_watched_dir = os.path.join( a_case_dir, 'processor0' )
-    import os; a_listdir = os.listdir( a_watched_dir )
+    import os; a_current_dir_list = set( os.listdir( a_watched_dir ) )
     
     from cloudflu.amazon.s3 import TRootObject
     a_root_object = TRootObject.get( AWS_ACCESS_KEY_ID, AWS_SECRET_ACCESS_KEY )
@@ -163,23 +174,29 @@ def main() :
             except:
                 break
             
-            import os; a_list_dir = os.listdir( a_watched_dir )
+            print_d( "a_current_dir_list = %s\n" % a_current_dir_list )
+            import os; a_fresh_dir_list = set( os.listdir( a_watched_dir ) )
+            print_d( "a_fresh_dir_list = %s\n" % a_fresh_dir_list )
 
-            for an_item in a_list_dir :
-                if an_item in a_listdir :
-                    continue
+            a_diff_dir_list = a_fresh_dir_list.difference( a_current_dir_list )
+            if a_diff_dir_list == set() :
+                continue
+
+            a_current_dir_list = a_fresh_dir_list
+
+            for an_item in a_diff_dir_list :
                 
+                print_d( "an_item = %s\n" % an_item )
                 a_worker_pool.charge( upload_timedata, ( a_root_object, a_study_name, a_booked,
                                                          an_upload_seed_size, a_number_threads, a_socket_timeout,
-                                                         a_case_dir, an_item ) )
+                                                         a_case_dir, an_item, a_current_dir_list ) )
                 if a_time_log == True :
                     a_worker_pool.charge( upload_timelog, ( a_root_object, a_study_name, a_booked,
                                                             an_upload_seed_size, a_number_threads, a_socket_timeout,
                                                             an_item, a_log_file ) )
                     pass
                 pass
-            
-            a_listdir = a_list_dir
+            pass
         except:
             import sys, traceback
             traceback.print_exc( file = sys.stderr )
@@ -200,7 +217,15 @@ def main() :
         an_additional_args += " --booked"
         pass
 
-    sh_command( "%s %s" % ( a_finish_hook, an_additional_args ) )
+    try:
+        sh_command( "%s %s" % ( a_finish_hook, an_additional_args ) )
+    except OSError, exc :
+        print "filename = %s\nstrerror = %s\errno = %s" % \
+            ( exc.filename, exc.strerror, exc.errno )
+    except Exception :
+        from cloudflu.common import print_traceback
+        print_traceback()
+        pass
 
 
     print_d( "\n------------------------ Sealing the given study --------------------------\n" )
