@@ -31,7 +31,7 @@ def usage_description() :
     an_usage_description = ' "mpirun --hostfile ~/.openmpi_hostfile -x LD_LIBRARY_PATH -x PATH -np ${a_number_processors} ${application} -case . -parallel"'
     an_usage_description += " --case-dir='.'"
     an_usage_description += " --solver-log='log.solver-run'"
-    an_usage_description += " --watched-keyword='ExecutionTime = '"
+    an_usage_description += " --watched-keyword='Time = |End'"
     
     return an_usage_description
 
@@ -44,23 +44,30 @@ a_container.add_option( TransientOption( "--case-dir",
                                          metavar = "< location of files inside of the study >",
                                          action = "store",
                                          dest = "case_dir",
-                                         help = "('%default', by default)",
+                                         help = "('%default', if not specified)",
                                          default = '.' ) )
 
 a_container.add_option( TransientOption( "--solver-log",
                                          metavar = "< location of files inside of the study >",
                                          action = "store",
                                          dest = "solver_log",
-                                         help = "('%default', by default)",
+                                         help = "('%default', if not specified)",
                                          default = 'log.solver-run' ) )
 
 a_container.add_option( TransientOption( "--watched-keyword",
                                          metavar = "< location of files inside of the study >",
                                          action = "store",
                                          dest = "watched_keyword",
-                                         help = "('%default', by default)",
+                                         help = "('%default', if not specified)",
                                          default = 'ExecutionTime = ' ) )
 
+a_container.add_option( TransientOption( "--finish-hook",
+                                         metavar = "< executable to be run at the solver finish >",
+                                         action = "store",
+                                         dest = "finish_hook",
+                                         help = "('%default', if not specified)",
+                                         default = 'cloudflu-timestamps-hook' ) )
+
 a_container.add_option( TransientOption( "--time-log",
                                          metavar = "< upload solver log per each timestamp >",
                                          action = "store_true",
@@ -92,21 +99,24 @@ def extract( the_option_parser ) :
     a_watched_keyword = an_options.watched_keyword
     print_d( "a_watched_keyword = '%s'\n" % a_watched_keyword )
 
+    a_finish_hook = an_options.finish_hook
+
     a_time_log = an_options.time_log
 
-    return a_solver_run, a_case_dir, a_solver_log, a_watched_keyword, a_time_log
+    return a_solver_run, a_case_dir, a_solver_log, a_watched_keyword, a_time_log, a_finish_hook
 
 
 #--------------------------------------------------------------------------------------
-def compose( the_solver_run, the_case_dir, the_solver_log, the_watched_keyword, the_time_log ) :
+def compose( the_solver_run, the_case_dir, the_solver_log, the_watched_keyword, the_time_log, the_finish_hook ) :
     a_compose = "'%s'" % the_solver_run
     a_compose += " --case-dir='%s'" % the_case_dir
     a_compose += " --solver-log='%s'" % the_solver_log
     a_compose += " --watched-keyword='%s'" % the_watched_keyword
+    a_compose += " --finish-hook='%s'" % the_finish_hook
 
     if the_time_log == True :
         a_compose += " --time-log"
-        pass        
+        pass
     
     return a_compose
 
