@@ -23,7 +23,8 @@
 
 #------------------------------------------------------------------------------------------
 """
-This script is responsible for efficient uploading of multi file data
+Finishes uploading specified set of data into ''study''. 
+This is the second and last step for macro ''[[cloudflu-study-upload]]'' utility.
 """
 
 
@@ -122,40 +123,31 @@ def upload_file( the_file_object, the_number_threads, the_printing_depth ) :
     return upload_seeds( the_file_object, a_working_dir, the_number_threads, the_printing_depth + 1 )
 
 
-#------------------------------------------------------------------------------------------
-def upload_files( the_study_object, the_number_threads, the_printing_depth ) :
-    a_worker_pool = WorkerPool( the_number_threads )
-
-    for a_file_object in the_study_object :
-        print_d( "a_file_object = %s\n" % a_file_object, the_printing_depth )
-
-        a_worker_pool.charge( upload_file, ( a_file_object, the_number_threads, the_printing_depth + 1 ) )                    
-        pass
-
-    a_worker_pool.shutdown()
-    a_worker_pool.join()
-    pass
-
-
 #--------------------------------------------------------------------------------------
-def entry_point( the_study_object, the_located_files, the_number_threads ) :
+def entry_point( the_study_object, the_located_files, the_number_threads, the_socket_timeout ) :
     a_spent_time = Timer()
     
+    a_worker_pool = WorkerPool( the_number_threads )
+    
+    a_socket_timeout = the_socket_timeout * the_number_threads * the_number_threads
+    import socket; socket.setdefaulttimeout( a_socket_timeout )
+
     if the_located_files == None :
-        upload_files( the_study_object, the_number_threads, 0 )
+        for a_file_object in the_study_object :
+            print_d( "a_file_object = %s\n" % a_file_object, 0 )
+            a_worker_pool.charge( upload_file, ( a_file_object, the_number_threads, 1 ) )                    
+            pass
         pass
     else :
-        a_worker_pool = WorkerPool( the_number_threads )
-        
         for a_located_file in the_located_files:
             a_file_object = TFileObject.get( the_study_object, a_located_file )
             a_worker_pool.charge( upload_file, ( a_file_object, the_number_threads, 0 ) )                    
             pass
-        
-        a_worker_pool.shutdown()
-        a_worker_pool.join()
         pass
     
+    a_worker_pool.shutdown()
+    a_worker_pool.join()
+
     print_d( "a_spent_time = %s, sec\n" % a_spent_time )
 
     return the_study_object
@@ -202,7 +194,7 @@ def main() :
     
     AWS_ACCESS_KEY_ID, AWS_SECRET_ACCESS_KEY = amazon.security_options.extract( an_option_parser )
 
-    common.communication_options.extract( an_option_parser )
+    a_socket_timeout = common.communication_options.extract( an_option_parser )
     
     a_number_threads = common.concurrency_options.extract( an_option_parser )
 
@@ -229,7 +221,7 @@ def main() :
 
 
     print_i( "-------------------------- Running actual functionality -------------------------\n" )
-    entry_point( a_study_object, a_located_files, a_number_threads )
+    entry_point( a_study_object, a_located_files, a_number_threads, a_socket_timeout )
 
 
     print_i( "------------------- Printing succussive pipeline arguments ----------------------\n" )
