@@ -37,7 +37,7 @@ a_container = OptionGroup( 'amazon.cluster' )
 
 a_container.add_option( PersistentOption( "--instance-type",
                                           metavar = "< EC2 instance type : 'c1.xlarge' or 'm1.large', for example >",
-                                          choices = [ 'm1.large', 'c1.xlarge', 'm1.xlarge', ' m2.xlarge', 'm2.2xlarge', 'm2.4xlarge', 'c1.medium' ],
+                                          choices = [ 'cc1.4xlarge', 't1.micro', 'm1.large', 'c1.xlarge', 'm1.xlarge', ' m2.xlarge', 'm2.2xlarge', 'm2.4xlarge', 'c1.medium' ],
                                           action = "store",
                                           dest = "instance_type",
                                           help = "('%default', by default)",
