@@ -26,6 +26,48 @@ from cloudflu.common import print_e, print_d, WorkerPool
 import os, os.path, hashlib
 
 
+#--------------------------------------------------------------------------------------
+def get_bucket_reliably( the_s3_conn, the_bucket_name ) :
+    a_bucket = the_s3_conn.get_bucket( the_bucket_name )
+
+    """ To check the bucket, whether it is ready to work or not"""
+    from boto.s3.key import Key; import uuid
+    try : 
+        a_key = Key( a_bucket, str( uuid.uuid4() ) )
+        a_key.set_contents_from_string( '' )
+        a_key.delete()
+        print_d( 'get - checked - %s\n' % a_bucket )
+    except Exception, exc:
+        # from cloudflu.common import print_traceback
+        # print_traceback()
+        raise exc
+
+    return a_bucket
+
+
+#--------------------------------------------------------------------------------------
+def create_bucket_reliably( the_s3_conn, the_bucket_name, the_location = '' ) :
+    a_bucket = None
+
+    """ To check the bucket, whether it is ready to work or not"""
+    while True :
+        from boto.s3.key import Key; import uuid
+        try : 
+            a_bucket = the_s3_conn.create_bucket( the_bucket_name, location = the_location )
+            a_key = Key( a_bucket, str( uuid.uuid4() ) )
+            a_key.set_contents_from_string( '' )
+            a_key.delete()
+            print_d( 'create - checked - %s\n' % a_bucket )
+            break
+        except Exception, exc:
+            from cloudflu.common import print_traceback
+            print_traceback()
+            continue
+        pass
+
+    return a_bucket
+
+
 #--------------------------------------------------------------------------------------
 class TRootObject :
     "Represents S3 dedicated implementation of study root"
@@ -66,9 +108,9 @@ class TRootObject :
 
         a_bucket = None
         try :
-            a_bucket = a_s3_conn.get_bucket( a_bucket_name )
+            a_bucket = get_bucket_reliably( a_s3_conn, a_bucket_name )
         except :
-            a_bucket = a_s3_conn.create_bucket( a_bucket_name )
+            a_bucket = create_bucket_reliably( a_s3_conn, a_bucket_name )
             pass
         
         return TRootObject( a_s3_conn, a_bucket, an_id )
@@ -349,10 +391,11 @@ class TStudyObject( TSealingObject ) :
         a_bucket_name = create_region_bucket_name( the_root_object._bucket.name, the_location )
         
         try:
-           a_bucket = the_root_object._connection.get_bucket( a_bucket_name )
+            a_bucket = get_bucket_reliably( the_root_object._connection, a_bucket_name )
         except:
-           a_bucket = the_root_object._connection.create_bucket( a_bucket_name, location = the_location )
-           
+            a_bucket = create_bucket_reliably( the_root_object._connection, a_bucket_name, the_location )
+            pass
+
         return TStudyObject( the_root_object, a_study_key, a_study_props_key, a_bucket, an_api_version )
 
     @staticmethod
@@ -373,7 +416,7 @@ class TStudyObject( TSealingObject ) :
             from cloudflu.common import print_traceback
             print_traceback()
 
-            raise NameError( "There is no '%s' study" % the_study_name )
+            raise NameError( "There is no '%s' study" % the_study_key_name )
             pass
 
         a_location = None
@@ -392,7 +435,7 @@ class TStudyObject( TSealingObject ) :
         a_bucket_name = create_region_bucket_name( the_root_object._bucket.name, a_location )
         a_bucket = None
         try: # in case of broken entities
-            a_bucket = the_root_object._connection.get_bucket( a_bucket_name )
+            a_bucket = get_bucket_reliably( the_root_object._connection, a_bucket_name )
         except :
             import sys, traceback
             traceback.print_exc( file = sys.stderr )
