@@ -204,7 +204,7 @@ def create_testing_bucket( AWS_ACCESS_KEY_ID, AWS_SECRET_ACCESS_KEY, the_region
     import uuid
     a_bucket_name = "config-" + str( uuid.uuid4() )
     a_bucket = a_conn.create_bucket( a_bucket_name, location = the_region )
-    
+
     return a_bucket
 
 
@@ -259,7 +259,7 @@ def measure_download_time( the_bucket, the_filesize ):
 
 #--------------------------------------------------------------------------------------
 def search_best_region( the_nb_attempts, AWS_ACCESS_KEY_ID, AWS_SECRET_ACCESS_KEY ):
-    print_d( "looking for \"best\" region ...\n" )
+    print_d( "looking for \"the best\" region ...\n" )
     a_test_filesize = 8192
     
     # Prepare buckets in different regions and dictionary for speed values 
@@ -297,7 +297,7 @@ def search_best_region( the_nb_attempts, AWS_ACCESS_KEY_ID, AWS_SECRET_ACCESS_KE
     a_best_average_speed = an_average_speeds[ 0 ]
     
     a_best_region = average_speed2region[ a_best_average_speed ]   
-    print_d( "\nfastest region - '%s'\n\n" % a_best_region )
+    print_d( "\nthe fastest region - '%s'\n\n" % a_best_region )
 
     a_first_stats = {}
     # a_first_stats[ a_test_filesize ] = a_region2speeds[ a_best_region ] # further, we use this values, only for "upload" case
